@@ -1,4 +1,5 @@
 #!/usr/bin/ruby -w
+# encoding: utf-8
 
 $:.unshift("lib/")
 
@@ -130,31 +131,34 @@ class OggInfoTest < Test::Unit::TestCase
     end
   end
 
+  def test_writing_to_spedial_filenames
+    tf = generate_ogg
+    filename = "fichier éé.ogg"
+    FileUtils.cp(tf.path, filename)
+    begin
+      OggInfo.open(tf.path) do |ogg|
+        ogg.tag.title = "a"*200
+      end
+      #system("ls", "-l", filename)
+    ensure
+      FileUtils.rm_f(filename) 
+    end
+  end
+
+  def test_good_writing_of_utf8_strings
+    tag = { "title" => "this is a éé utf8 string",
+            "artist" => "and è another one à"}
+    tag_test("tag_writing", tag)
+  end
+
   def test_tag_writing
-    tag_test("title" => generate_random_string, "artist" => generate_random_string )
+    data = "a"*256
+    tag_test("tag_writing", "title" => data, "artist" => data )
   end
 
   def test_big_tags
-    tag_test("title" => generate_random_string(60000), "artist" => generate_random_string(60000) )
-  end
-  
-
-  def test_charset
-    tf = generate_ogg
-    OggInfo.open(tf.path, "utf-8") do |ogg|
-      ogg.tag["title"] = "hello\303\251"
-    end
-
-    OggInfo.open(tf.path, "iso-8859-1") do |ogg|
-      if RUBY_VERSION[0..2] == '1.8'
-        assert_equal "hello\xe9", ogg.tag["title"] 
-      else
-        string = ''
-        string.force_encoding 'iso-8859-1'
-        [104, 101, 108, 108, 111, 233].each {|chr| string << chr}
-        assert_equal string, ogg.tag["title"] 
-      end
-    end
+    data = "a"*60000
+    tag_test("big_tags", "title" => data, "artist" => data )
   end
 
   def test_should_not_fail_when_input_is_truncated
@@ -189,7 +193,6 @@ class OggInfoTest < Test::Unit::TestCase
 
   protected
 
-
   def generate_ogg
     generated_ogg_file_path = File.join(File.dirname(__FILE__), "test.ogg")
     unless test(?f, generated_ogg_file_path)
@@ -202,10 +205,6 @@ class OggInfoTest < Test::Unit::TestCase
     tf
   end
 
-  def generate_random_string(size = 256)
-    File.read("/dev/urandom", size)
-  end
-
   def generate_truncated_ogg
     valid_ogg = generate_ogg
     tf = Tempfile.new("ruby-ogginfo")
@@ -215,7 +214,7 @@ class OggInfoTest < Test::Unit::TestCase
     tf
   end
 
-  def tag_test(tag) 
+  def tag_test(test_name, tag) 
     tf = generate_ogg
 
     OggInfo.open(tf.path) do |ogg|
@@ -225,6 +224,14 @@ class OggInfoTest < Test::Unit::TestCase
     OggInfo.open(tf.path) do |ogg|
       assert_equal tag, ogg.tag
     end
+    system("cp #{tf.path} /tmp/test_#{RUBY_VERSION}_#{test_name}.ogg")
     test_length
+    assert_nothing_raised do
+      io = open(tf.path)
+      reader = Ogg::Reader.new(io)
+      reader.each_pages do |page|
+        page
+      end
+    end
   end
 end
